@@ -21,17 +21,21 @@ class SR3(BaseOptimizer):
         0.5\\|y-Xw\\|^2_2 + \\lambda \\times R(v)
         + (0.5 / \\nu)\\|w-v\\|^2_2
 
-    where :math:`R(v)` is a regularization function. See the following reference
+    where :math:`R(v)` is a regularization function. See the following references
     for more details:
 
         Zheng, Peng, et al. "A unified framework for sparse relaxed
         regularized regression: Sr3." IEEE Access 7 (2018): 1404-1423.
 
+        Champion, Kathleen, et al. "A unified sparse optimization framework
+        to learn parsimonious physics-informed models from data."
+        arXiv preprint arXiv:1906.10612 (2019).
+
     Parameters
     ----------
     threshold : float, optional (default 0.1)
         Determines the strength of the regularization. When the
-        regularization function R is the l0 norm, the regularization
+        regularization function R is the L0 norm, the regularization
         is equivalent to performing hard thresholding, and lambda
         is chosen to threshold at the value given by this parameter.
         This is equivalent to choosing lambda = threshold^2 / (2 * nu).
@@ -45,9 +49,9 @@ class SR3(BaseOptimizer):
         Tolerance used for determining convergence of the optimization
         algorithm.
 
-    thresholder : string, optional (default 'l0')
+    thresholder : string, optional (default 'L0')
         Regularization function to use. Currently implemented options
-        are 'l0' (l0 norm), 'l1' (l1 norm), and 'cad' (clipped
+        are 'L0' (L0 norm), 'L1' (L1 norm), and 'CAD' (clipped
         absolute deviation).
 
     trimming_fraction : float, optional (default 0.0)
@@ -68,7 +72,7 @@ class SR3(BaseOptimizer):
     normalize : boolean, optional (default False)
         This parameter is ignored when fit_intercept is set to False. If True,
         the regressors X will be normalized before regression by subtracting
-        the mean and dividing by the l2-norm.
+        the mean and dividing by the L2-norm.
 
     copy_X : boolean, optional (default True)
         If True, X will be copied; else, it may be overwritten.
@@ -113,7 +117,7 @@ class SR3(BaseOptimizer):
         threshold=0.1,
         nu=1.0,
         tol=1e-5,
-        thresholder="l0",
+        thresholder="L0",
         trimming_fraction=0.0,
         trimming_step_size=1.0,
         max_iter=30,
@@ -172,15 +176,12 @@ class SR3(BaseOptimizer):
 
     def _update_trimming_array(self, coef_full, trimming_array, trimming_grad):
         trimming_array = trimming_array - self.trimming_step_size * trimming_grad
-        trimming_array = self.cSimplexProj(trimming_array, self.trimming_fraction)
+        trimming_array = self._capped_simplex_projection(
+            trimming_array, self.trimming_fraction
+        )
         self.history_trimming_.append(trimming_array)
         return trimming_array
 
-    def _trimming_grad(self, x, y, coef_full, trimming_array):
-        """gradient for the trimming variable"""
-        R2 = (y - x.dot(coef_full)) ** 2
-        return 0.5 * np.sum(R2, axis=1)
-
     def _convergence_criterion(self):
         """Calculate the convergence criterion for the optimization"""
         this_coef = self.history_[-1]
@@ -253,7 +254,7 @@ class SR3(BaseOptimizer):
             self.trimming_array = trimming_array
 
     @staticmethod
-    def cSimplexProj(trimming_array, trimming_fraction):
+    def _capped_simplex_projection(trimming_array, trimming_fraction):
         """projected onto the capped simplex"""
         a = np.min(trimming_array) - 1.0
         b = np.max(trimming_array) - 0.0
